@@ -38,7 +38,7 @@ func isStrInArray(str string, array []string) bool {
 }
 
 func doAction(cmd string, args []string) error {
-	fmt.Println("run cmd", cmd, args)
+	fmt.Println("run cmd", cmd)
 	out, err := exec.Command(cmd, args...).CombinedOutput()
 	if err != nil {
 		fmt.Printf("[doAction] exec '%s' failed: %s, %v\n", cmd, string(out), err)
