@@ -26,7 +26,30 @@ import (
 	"github.com/stretchr/testify/assert"
 )
 
-func Test_ConfigFilePath(t *testing.T) {
-	os.Setenv("XDG_CONFIG_HOME", "../testdata/.config")
-	assert.Equal(t, ConfigFilePath("launcher/test.ini"), "../testdata/.config/launcher/test.ini")
+func TestConfigFilePath(t *testing.T) {
+	type args struct {
+		name string
+	}
+	tests := []struct {
+		name       string
+		configHome string
+		args       args
+		want       string
+	}{
+		{
+			name:       "ConfigFilePath",
+			configHome: "../testdata/.config",
+			args:       args{name: "launcher/test.ini"},
+			want:       "../testdata/.config/launcher/test.ini",
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			os.Setenv("XDG_CONFIG_HOME", tt.configHome)
+			defer os.Unsetenv("XDG_CONFIG_HOME")
+
+			got := ConfigFilePath(tt.args.name)
+			assert.Equal(t, tt.want, got)
+		})
+	}
 }
