@@ -20,12 +20,13 @@
 package main
 
 import (
-	"pkg.deepin.io/dde/daemon/langselector"
-	"pkg.deepin.io/lib/gettext"
+	"github.com/linuxdeepin/go-lib/gettext"
+	"github.com/linuxdeepin/dde-daemon/langselector"
 )
 
 func main() {
 	gettext.InitI18n()
+	gettext.BindTextdomainCodeset("dde-daemon", "UTF-8")
 	gettext.Textdomain("dde-daemon")
 	langselector.Run()
 }
