@@ -21,14 +21,14 @@ package dbus
 
 import (
 	"github.com/godbus/dbus"
-	"github.com/linuxdeepin/go-dbus-factory/com.deepin.daemon.accounts"
+	accounts "github.com/linuxdeepin/go-dbus-factory/com.deepin.daemon.accounts"
 )
 
-func NewAccounts(systemConn *dbus.Conn) *accounts.Accounts {
+func NewAccounts(systemConn *dbus.Conn) accounts.Accounts {
 	return accounts.NewAccounts(systemConn)
 }
 
-func NewUserByName(systemConn *dbus.Conn, name string) (*accounts.User, error) {
+func NewUserByName(systemConn *dbus.Conn, name string) (accounts.User, error) {
 	m := NewAccounts(systemConn)
 	userPath, err := m.FindUserByName(0, name)
 	if err != nil {
@@ -37,7 +37,7 @@ func NewUserByName(systemConn *dbus.Conn, name string) (*accounts.User, error) {
 	return accounts.NewUser(systemConn, dbus.ObjectPath(userPath))
 }
 
-func NewUserByUid(systemConn *dbus.Conn, uid string) (*accounts.User, error) {
+func NewUserByUid(systemConn *dbus.Conn, uid string) (accounts.User, error) {
 	m := NewAccounts(systemConn)
 	userPath, err := m.FindUserById(0, uid)
 	if err != nil {
