@@ -20,7 +20,7 @@
 package screenedge
 
 import (
-	"pkg.deepin.io/gir/gio-2.0"
+	"github.com/linuxdeepin/go-gir/gio-2.0"
 )
 
 type Settings struct {
