@@ -1,8 +1,8 @@
 package uadpagent
 
 import (
-	"pkg.deepin.io/dde/daemon/loader"
-	"pkg.deepin.io/lib/log"
+	"github.com/linuxdeepin/go-lib/log"
+	"github.com/linuxdeepin/dde-daemon/loader"
 )
 
 func init() {
@@ -25,30 +25,30 @@ func (m *Module) GetDependencies() []string {
 }
 
 func (m *Module) Start() error {
-	service := loader.GetService()
+	// service := loader.GetService()
 
-	if m.uAgent != nil {
-		return nil
-	}
+	// if m.uAgent != nil {
+	// 	return nil
+	// }
 
-	var err error
-	m.uAgent, err = newUadpAgent(service)
-	if err != nil {
-		logger.Warning("failed to newUadpAgent:", err)
-		return err
-	}
+	// var err error
+	// m.uAgent, err = newUadpAgent(service)
+	// if err != nil {
+	// 	logger.Warning("failed to newUadpAgent:", err)
+	// 	return err
+	// }
 
-	err = service.Export(dbusPath, m.uAgent)
-	if err != nil {
-		logger.Warning("failed to Export uAgent:", err)
-		return err
-	}
+	// err = service.Export(dbusPath, m.uAgent)
+	// if err != nil {
+	// 	logger.Warning("failed to Export uAgent:", err)
+	// 	return err
+	// }
 
-	err = service.RequestName(dbusServiceName)
-	if err != nil {
-		logger.Warning("failed to RequestName:", err)
-		return err
-	}
+	// err = service.RequestName(dbusServiceName)
+	// if err != nil {
+	// 	logger.Warning("failed to RequestName:", err)
+	// 	return err
+	// }
 
 	return nil
 }
