@@ -29,15 +29,27 @@ import (
 	"time"
 
 	dbus "github.com/godbus/dbus"
+	"github.com/linuxdeepin/dde-api/powersupply"
+	"github.com/linuxdeepin/dde-api/powersupply/battery"
 	gudev "github.com/linuxdeepin/go-gir/gudev-1.0"
 	"github.com/linuxdeepin/go-lib/arch"
 	"github.com/linuxdeepin/go-lib/dbusutil"
-	"github.com/linuxdeepin/dde-api/powersupply"
-	"github.com/linuxdeepin/dde-api/powersupply/battery"
+	"github.com/linuxdeepin/go-lib/strv"
 )
 
 var noUEvent bool
 
+const configManagerId = "org.desktopspec.ConfigManager"
+//内核文档：https://docs.kernel.org/admin-guide/pm/cpufreq.html#generic-scaling-governors
+var cpupowerArr = []string {
+	"performance",
+	"powersave",
+	"userspace",
+	"ondemand",
+	"conservative",
+	"schedutil",
+}
+
 func init() {
 	if arch.Get() == arch.Sunway {
 		noUEvent = true
@@ -49,11 +61,12 @@ func init() {
 
 // https://www.kernel.org/doc/Documentation/power/power_supply_class.txt
 type Manager struct {
-	service     *dbusutil.Service
-	batteries   map[string]*Battery
-	batteriesMu sync.Mutex
-	ac          *AC
-	gudevClient *gudev.Client
+	service       *dbusutil.Service
+	systemSigLoop *dbusutil.SignalLoop
+	batteries     map[string]*Battery
+	batteriesMu   sync.Mutex
+	ac            *AC
+	gudevClient   *gudev.Client
 
 	// 电池是否电量低
 	batteryLow bool
@@ -87,6 +100,9 @@ type Manager struct {
 	// 开启节能模式时降低亮度的百分比值
 	PowerSavingModeBrightnessDropPercent uint32 `prop:"access:rw"`
 
+	// 开启节能模式时保存的数据
+	PowerSavingModeBrightnessData string `prop:"access:rw"`
+
 	// CPU频率调节模式，支持powersave和performance
 	CpuGovernor string
 
@@ -96,6 +112,10 @@ type Manager struct {
 	// 是否支持Boost
 	IsHighPerformanceSupported bool
 
+	// 性能模式-平衡模式dsg
+	balanceScalingGovernor     string
+	configManagerPath          dbus.ObjectPath
+
 	// 当前模式
 	Mode string
 
@@ -118,6 +138,42 @@ type Manager struct {
 	}
 }
 
+func (m *Manager) initDsgConfig(conn *dbus.Conn) error {
+	// 加载dsg配置
+	systemConnObj := conn.Object(configManagerId, "/")
+	err := systemConnObj.Call(configManagerId+".acquireManager", 0, "org.deepin.dde.daemon", "org.deepin.dde.daemon.power", "").Store(&m.configManagerPath)
+	if err != nil {
+		logger.Warning(err)
+		return err
+	}
+	err = dbusutil.NewMatchRuleBuilder().Type("signal").
+		PathNamespace(string(m.configManagerPath)).
+		Interface("org.desktopspec.ConfigManager.Manager").
+		Member("valueChanged").Build().AddTo(conn)
+	if err != nil {
+		logger.Warning(err)
+		return err
+	}
+	return nil
+}
+
+func (m *Manager) getDsgData(key string) string {
+	systemConn, err := dbus.SystemBus()
+	if err != nil {
+		logger.Warning("getDsgData systemConn err: ", err)
+		return ""
+	}
+	systemConnObj := systemConn.Object("org.desktopspec.ConfigManager", m.configManagerPath)
+	var value string
+	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value",0, key).Store(&value)
+	if err != nil {
+		logger.Warningf("getDsgData key : %s. err : %s", key, err)
+		return ""
+	}
+	logger.Infof(" systemPowerManager getDsgData key : %s , value : %s", key, value)
+	return value
+}
+
 func newManager(service *dbusutil.Service) (*Manager, error) {
 	m := &Manager{
 		service:           service,
@@ -129,6 +185,21 @@ func newManager(service *dbusutil.Service) (*Manager, error) {
 		m.destroy()
 		return nil, err
 	}
+	systemBus, err := dbus.SystemBus()
+	if err != nil {
+		return nil, err
+	}
+	m.systemSigLoop = dbusutil.NewSignalLoop(systemBus, 10)
+	m.systemSigLoop.Start()
+	m.initDsgConfig(systemBus)
+
+	cpuGovernor := m.getDsgData("BalanceCpuGovernor")
+	if strv.Strv(cpupowerArr).Contains(cpuGovernor) {
+		m.balanceScalingGovernor = cpuGovernor
+	} else {
+		m.balanceScalingGovernor = "ondemand"
+		logger.Warning(" illegal string cpuGovernor : ", cpuGovernor)
+	}
 	return m, nil
 }
 
@@ -380,6 +451,7 @@ func (m *Manager) destroy() {
 		m.gudevClient.Unref()
 		m.gudevClient = nil
 	}
+	m.systemSigLoop.Stop()
 }
 
 const configFile = "/var/lib/dde-daemon/power/config.json"
@@ -448,7 +520,7 @@ func (m *Manager) saveConfig() error {
 	m.PropsMu.RUnlock()
 
 	dir := filepath.Dir(configFile)
-	err := os.MkdirAll(dir, 0755)
+	err := os.MkdirAll(dir, 0755) // #nosec G301
 	if err != nil {
 		return err
 	}
@@ -457,7 +529,7 @@ func (m *Manager) saveConfig() error {
 	if err != nil {
 		return err
 	}
-	return ioutil.WriteFile(configFile, content, 0644)
+	return ioutil.WriteFile(configFile, content, 0644) // #nosec G306
 }
 
 func (m *Manager) doSetMode(mode string) error {
@@ -465,8 +537,11 @@ func (m *Manager) doSetMode(mode string) error {
 	switch mode {
 	case "balance": // governor=performance boost=false
 		m.setPropPowerSavingModeEnabled(false)
-
-		m.doSetCpuGovernor("performance")
+		logger.Info("[doSetMode] balanceScalingGovernor : ", m.balanceScalingGovernor)
+		err = m.doSetCpuGovernor(m.balanceScalingGovernor)
+		if err != nil {
+			logger.Warning(err)
+		}
 
 		if m.IsHighPerformanceSupported {
 			err = m.doSetCpuBoost(false)
@@ -474,7 +549,10 @@ func (m *Manager) doSetMode(mode string) error {
 	case "powersave": // governor=powersave boost=false
 		m.setPropPowerSavingModeEnabled(true)
 
-		m.doSetCpuGovernor("powersave")
+		err = m.doSetCpuGovernor("powersave")
+		if err != nil {
+			logger.Warning(err)
+		}
 
 		if m.IsHighPerformanceSupported {
 			err = m.doSetCpuBoost(false)
@@ -486,7 +564,10 @@ func (m *Manager) doSetMode(mode string) error {
 		}
 		m.setPropPowerSavingModeEnabled(false)
 
-		m.doSetCpuGovernor("performance")
+		err = m.doSetCpuGovernor("performance")
+		if err != nil {
+			logger.Warning(err)
+		}
 
 		err = m.doSetCpuBoost(true)
 
