@@ -1,8 +1,8 @@
 package systeminfo
 
 import (
-	"pkg.deepin.io/dde/daemon/loader"
-	"pkg.deepin.io/lib/log"
+	"github.com/linuxdeepin/go-lib/log"
+	"github.com/linuxdeepin/dde-daemon/loader"
 )
 
 var logger = log.NewLogger("daemon/systeminfo")
@@ -16,11 +16,11 @@ type Module struct {
 	*loader.ModuleBase
 }
 
-func (m Module) GetDependencies() []string {
+func (m *Module) GetDependencies() []string {
 	return nil
 }
 
-func (m Module) Start() error {
+func (m *Module) Start() error {
 	if m.m != nil {
 		return nil
 	}
@@ -57,7 +57,7 @@ func (m Module) Start() error {
 	return nil
 }
 
-func (m Module) Stop() error {
+func (m *Module) Stop() error {
 	return nil
 }
 
